<?php

/**
 * @file
 * The admin settings for the Website shtudown module.
 */

/**
 * Settings page callback.
 */
function shutdown_settings_form() {
  $form['shutdown_enable'] = array(
    '#type' => 'checkbox',
    '#title' => t('Shut down website?'),
    '#default_value' => variable_get('shutdown_enable', 0),
    '#description' => t('If you enable this option, your website will be closed for all visitors except those who have adequate permission.'),
  );
  $form['shutdown_redirect_page'] = array(
    '#type' => 'textfield',
    '#title' => t('Redirect page'),
    '#default_value' => variable_get('shutdown_redirect_page', ''),
    '#description' => t('Specify the page to redirect to. This could be a Drupal internal path, an URL or a file relative to drupal directory.'),
  );
  $form['shutdown_excluded_paths'] = array(
    '#type' => 'textarea',
    '#title' => t('Paths to exclude'),
    '#default_value' => variable_get('shutdown_excluded_paths', ''),
    '#description' => t('Specify the paths that should remain accessible. One path per line.'),
  );

  $form['advanced_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Advanced settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['advanced_settings']['shutdown_allow_http_cron'] = array(
    '#type' => 'checkbox',
    '#title' => t('Allow cron.php to be run during website closed?'),
    '#default_value' => variable_get('shutdown_allow_http_cron', 1),
    '#description' => t('If you disable this option, cron requests made through cron.php file will be ignored.'),
  );

  $form['#submit'][] = 'shutdown_settings_form_submit';

  return system_settings_form($form);
}

/**
 * Validate function for shutdown_settings_form().
 */
function shutdown_settings_form_validate($form, &$form_state) {
  $excluded_paths = explode(PHP_EOL, $form_state['values']['shutdown_excluded_paths']);
  $redirect_page = $form_state['values']['shutdown_redirect_page'];

  // In case website should be shut down, make sure redirect page is not empty.
  if ($form_state['values']['shutdown_enable'] && empty($redirect_page)) {
    form_set_error('shutdown_redirect_page', t('Please specify a redirect page'));
  }
  // If page is an external URL, make sure it is valid.
  elseif (url_is_external($redirect_page)) {
    if (!valid_url($redirect_page)) {
      form_set_error('shutdown_redirect_page', t('%page is not valid.', array('%page' => $redirect_page)));
    }
  }
  // Make sure redirect page is not index.php to avoid infinite redirections.
  elseif ($redirect_page == 'index.php') {
    form_set_error('shutdown_redirect_page', t('%page cannot be used for page redirection.', array('%page' => $redirect_page)));
  }
  // If page is an internal path, make sure it is in excluded paths to avoid
  // infinite redirections.
  elseif (menu_get_item($redirect_page) && !in_array($redirect_page, $excluded_paths)) {
    form_set_error('shutdown_redirect_page', t('%page should be added to excluded paths in order to avoid infinte loops.', array('%page' => $redirect_page)));
  }
}

/**
 * Submit function for shutdown_settings_form().
 */
function shutdown_settings_form_submit($form, &$form_state) {
  // If state did not change, do nothing.
  if (variable_get('shutdown_enable') == $form_state['values']['shutdown_enable']) {
    return;
  }

  switch ($form_state['values']['shutdown_enable']) {
    case 1:
      shutdown_shut_website();
      drupal_set_message(t('Website is now shut down.'), 'warning');
      break;

    case 0:
      shutdown_open_website();
      drupal_set_message(t('Website is now opened up.'));
      break;
  }
}
